@@ -14,7 +14,7 @@ def calculate_maxi_min_rjl(data):
         return {'max_rongjilv': '', 'min_rongjilv': ''}
 
     try:
-        lst = re.findall(r'[0-9]+[.][0-9]+', data)
+        lst = re.findall(r'[0-9|.]+', data)
         max_rongjilv = None
         min_rongjilv = None
         max_r = max(lst)
@@ -61,7 +61,7 @@ def calculate_maxi_min_lhl(data):
     if data is None or data=='':
         return {'max_lhl':'', 'min_lhl':''}
     try:
-        lst = re.findall(r'[0-9|.]+%', data)
+        lst = re.findall(r'[0-9|.]+[%]?', data)
         lst1 = [float(str(i).replace('%', '')) for i in lst if i]
         max_lhl = int(max(lst1))
         min_lhl = int(min(lst1))
@@ -106,7 +106,7 @@ def calculate_maxi_min_jzmd(data):
     if data is None or data == '':
         return {'max_jzmd': '', 'min_jzmd': ''}
     try:
-        lst = re.findall(r'[0-9|.]+%', data)
+        lst = re.findall(r'[0-9|.]+[%]?', data)
         lst1 = [float(str(i).replace('%', '')) for i in lst if i]
         max_jzmd = int(max(lst1))
         min_jzmd = int(min(lst1))
@@ -164,5 +164,7 @@ def read_csv():
 
 
 if __name__ == '__main__':
-    print(calculate_maxi_min_rjl('1.5-2.0'))
+    data='>=4'
+    lst = re.findall(r'[0-9|.]+[%]?', data)
+    print(calculate_maxi_min_lhl('>=4'))
 
